package com.zhiwei.manage.service;

import java.util.Date;
import java.util.List;

import com.zhiwei.manage.bean.Data;

public interface DataService {

	public void insert(Data data);

	public List<Data> findBySource(Date startTime, Date endTime, String source);

	public List<Data> findBytempName(Date startTime, Date endTime, String tempName);

	public List<Data> findByPt(Date startTime, Date endTime, String pt);
	// public List<Data> findByMethod(Date startTime, Date endTime, String method,
	// Object value);

	// public int findBySourceFromLibrary(Date startTime, Date endTime, String
	// source);
	public List<Data> findByPtDay(Date startTime, Date endTime, String pt);

	public List<Data> findByMethodAndParam(Date startTime, Date endTime, String method, String param);

	public List<String> findTmpNameByLikeParam(String param);

	// 根据配置获取数据
	// public long finCountByDayData(Date startDate, Date endDate, Template temp);
	//
	// public long finCountByDayData(Date startDate, Date endDate, String pt);
}
